@@ -45,7 +45,8 @@ jQuery( function ( $ ) {
 				);
 		}
 	});
-	$('.remove_url').live('click', function () {
+	
+	$( '#the-comment-list' ).on( 'click', '.remove_url', function () {
 		var thisId = $(this).attr('commentid');
 		var data = {
 			action: 'comment_author_deurl',
@@ -82,8 +83,7 @@ jQuery( function ( $ ) {
 		});
 
 		return false;
-	});
-	$('.akismet_undo_link_removal').live('click', function () {
+	}).on( 'click', '.akismet_undo_link_removal', function () {
 		var thisId = $(this).attr('cid');
 		var thisUrl = $(this).attr('href');
 		var data = {
@@ -177,7 +177,7 @@ jQuery( function ( $ ) {
 				'limit': limit
 			},
 			function(result) {
-				if (result.processed < limit) {
+				if (result.counts.processed < limit) {
 					window.location.reload();
 				}
 				else {
