@@ -4,11 +4,11 @@
  */
 /*
 Plugin Name: Akismet
-Plugin URI: http://akismet.com/
-Description: Used by millions, Akismet is quite possibly the best way in the world to <strong>protect your blog from spam</strong>. It keeps your site protected even while you sleep. To get started: 1) Click the "Activate" link to the left of this description, 2) <a href="http://akismet.com/get/">Sign up for an Akismet plan</a> to get an API key, and 3) Go to your Akismet configuration page, and save your API key.
-Version: 3.1.10
+Plugin URI: https://akismet.com/
+Description: Used by millions, Akismet is quite possibly the best way in the world to <strong>protect your blog from spam</strong>. It keeps your site protected even while you sleep. To get started: 1) Click the "Activate" link to the left of this description, 2) <a href="https://akismet.com/get/">Sign up for an Akismet plan</a> to get an API key, and 3) Go to your Akismet configuration page, and save your API key.
+Version: 3.2
 Author: Automattic
-Author URI: http://automattic.com/wordpress-plugins/
+Author URI: https://automattic.com/wordpress-plugins/
 License: GPLv2 or later
 Text Domain: akismet
 */
@@ -37,8 +37,8 @@ if ( !function_exists( 'add_action' ) ) {
 	exit;
 }
 
-define( 'AKISMET_VERSION', '3.1.10' );
-define( 'AKISMET__MINIMUM_WP_VERSION', '3.2' );
+define( 'AKISMET_VERSION', '3.2' );
+define( 'AKISMET__MINIMUM_WP_VERSION', '3.7' );
 define( 'AKISMET__PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
 define( 'AKISMET_DELETE_LIMIT', 100000 );
 
@@ -50,7 +50,7 @@ require_once( AKISMET__PLUGIN_DIR . 'class.akismet-widget.php' );
 
 add_action( 'init', array( 'Akismet', 'init' ) );
 
-if ( is_admin() ) {
+if ( is_admin() || ( defined( 'WP_CLI' ) && WP_CLI ) ) {
 	require_once( AKISMET__PLUGIN_DIR . 'class.akismet-admin.php' );
 	add_action( 'init', array( 'Akismet_Admin', 'init' ) );
 }
@@ -58,3 +58,6 @@ if ( is_admin() ) {
 //add wrapper class around deprecated akismet functions that are referenced elsewhere
 require_once( AKISMET__PLUGIN_DIR . 'wrapper.php' );
 
+if ( defined( 'WP_CLI' ) && WP_CLI ) {
+	require_once( AKISMET__PLUGIN_DIR . 'class.akismet-cli.php' );
+}
\ No newline at end of file
